@@ -812,7 +812,7 @@ def estimate_phase_beagle(
     gene = imported_variants.metadata['Gene']
     assembly = imported_variants.metadata['Assembly']
     region = core.get_region(gene, assembly=assembly)
-    beagle = f'{core.PROGRAM_PATH}/pypgx/api/beagle.28Jun21.220.jar'
+    beagle = f'{core.PROGRAM_PATH}/pypgx/api/beagle.22Jul22.46e.jar'
 
     metadata = imported_variants.copy_metadata()
     metadata['SemanticType'] = 'VcfFrame[Phased]'
@@ -833,6 +833,12 @@ def estimate_phase_beagle(
     if vf1.empty:
         return sdk.Archive(metadata, vf1)
 
+    # When the input VCF is chip data, make sure it doesn't contain
+    # chip-specific alleles such as 'I', 'D', 'N'. Otherwise, Beagle will
+    # throw an error.
+    if metadata['Platform'] == 'Chip':
+        vf1 = vf1.filter_gsa()
+
     # Beagle will throw an error if there is only one marker overlapping with
     # the reference panel in a given window. This typically occurs when the
     # input VCF has very few markers or only one marker. Therefore, these
@@ -842,12 +848,21 @@ def estimate_phase_beagle(
     variants2 = vf2.to_variants()
     common_variants = list(set(variants1).intersection(variants2))
 
-    if len(common_variants) == 1:
+    if len(common_variants) == 0:
+        warnings.warn("0 overlapping variants, skip statistical phasing")
+        vf3 = pyvcf.VcfFrame([], vf1.df[0:0])
+    elif len(common_variants) == 1:
+        warnings.warn("Only 1 overlapping variant, skip statistical phasing")
         (chrom, pos, ref, alt) = common.parse_variant(common_variants[0])
         df = vf1.df[vf1.df.POS == pos]
         vf3 = pyvcf.VcfFrame([], df)
         vf3 = vf3.pseudophase().strip()
     else:
+        # Beagle will throw an error if there are overlapping samples between
+        # the input VCF and the reference panel.
+        common_samples = list(set(vf1.samples) & set(vf2.samples))
+        if common_samples:
+            vf1 = vf1.rename({x: f'{x}_TEMP' for x in common_samples})
         with tempfile.TemporaryDirectory() as t:
             vf1.to_file(f'{t}/input.vcf')
             command = [
@@ -860,6 +875,8 @@ def estimate_phase_beagle(
             ]
             subprocess.run(command, check=True, stdout=subprocess.DEVNULL)
             vf3 = pyvcf.VcfFrame.from_file(f'{t}/output.vcf.gz')
+        if common_samples:
+            vf3 = vf3.rename({f'{x}_TEMP': x for x in common_samples})
         if has_chr_prefix:
             vf3 = vf3.update_chr_prefix('remove')
 
@@ -997,6 +1014,17 @@ def import_variants(
     else:
         vf = vcf.slice(region)
 
+    # The input VCF could contain duplicate variant records. In this case,
+    # warn the user about it and only keep the first record.
+    cols = ['CHROM', 'POS', 'REF', 'ALT']
+    if vf.duplicated(cols).any():
+        i = vf.duplicated(cols, keep=False)
+        s = vf.df[i].to_string(index=False)
+        warnings.warn("Input VCF contains duplicate variants sharing the "
+                      f"same {cols} values. Will drop duplicates except for "
+                      "the first occurrence:\n" + s)
+        vf = vf.drop_duplicates(cols)
+
     vf = vf.update_chr_prefix(mode='remove')
     vf = vf.strip('GT:AD:DP')
     vf = vf.add_af()
